@@ -4,8 +4,6 @@ from .config_update import (whether_update_config,
                             how_update_config,
                             store_mle_config,
                             print_mle_config)
-from .crypto_credentials import (encrypt_ssh_credentials,
-                                 decrypt_ssh_credentials)
 
 
 __all__ = [
@@ -15,6 +13,4 @@ __all__ = [
            "how_update_config",
            "store_mle_config",
            "print_mle_config",
-           "encrypt_ssh_credentials",
-           "decrypt_ssh_credentials"
           ]
