@@ -4,6 +4,7 @@ import random
 import numpy as np
 import platform
 import re
+import sys, select
 from typing import Union
 from dotmap import DotMap
 from datetime import datetime
@@ -120,7 +121,10 @@ def get_configs_ready(default_config_fname: str="configs/base_config.json",
         train_config.seed_id = int(cmd_args.seed_id)
         log_config.seed_id = "seed_" + str(cmd_args.seed_id)
     else:
-        log_config.seed_id = "seed_" + str(train_config.seed_id)
+        try:
+            log_config.seed_id = "seed_" + str(train_config.seed_id)
+        except:
+            log_config.seed_id = "seed_default"
     return train_config, net_config, log_config, extra_args
 
 
@@ -164,6 +168,27 @@ def ask_for_resource_to_run():
     return resource_to_run
 
 
+def ask_for_binary_input(question: str, default_answer: str="N"):
+    """ Ask user if they want to exec on remote resource. """
+    time_t = datetime.now().strftime("%m/%d/%Y %I:%M:%S %p")
+    q_str = f"{time_t} {question} [Y/N]"
+    print(q_str, end=' ')
+    sys.stdout.flush()
+    # Loop over experiments to delete until "N" given or timeout after 60 secs
+    answer = default_answer
+    while True:
+        i, o, e = select.select([sys.stdin], [], [], 60)
+        if (i):
+            answer = sys.stdin.readline().strip()
+            if answer in ["y", "n", "Y", "N"]:
+                break
+            else:
+                print("Please repeat your answer. [Y/N]")
+        else:
+            break
+    return answer in ["Y", "y"]
+
+
 def determine_resource() -> str:
     """ Check if cluster (sge/slurm) is available. """
     hostname = platform.node()
